finchan.event
==================================

.. automodule:: finchan.event

   Event
   --------------------
   .. autoclass:: Event
       :members:

   SysEvents:
   --------------------
   .. autoclass:: SysEvents
       :members:
